//use assert_cmd::prelude::*; // Add methods on commands
//use predicates::prelude::*;
use anyhow::Result;
use reef::Command;
//use std::process::Command; // Run programs // Used for writing assertions

//#[test]
fn main() -> Result<()> {
    match std::env::current_dir() {
        Ok(cur_dir) => {
            println!("cur_dir {}", cur_dir.display());
            let run_exe = cur_dir.join("target").join("debug").join("run.exe");
            if run_exe.exists() {
                println!("found {}", run_exe.display());

                let run = Command::new("run a b c").exec()?;
                println!("{:#?}", run);
            } else {
                panic!("unable to find to run executable");
            }
        }
        Err(e) => {
            println!("unable to get cur_dir {}", e);
        }
    };
    /*
    let mut cmd = Command::cargo_bin("run")?;
    cmd.arg("a").arg("b");

    cmd.assert().success().stdout(predicate::str::contains("a"));
    */
    Ok(())
}
